@@ -3,7 +3,6 @@
 # If you want to add a HTTP status code, you must add
 # an entry in httpcodelib.
 #-------------------------------------------------------
-# $Revision: 1.2 $ - $Author: eldy $ - $Date: 2008/11/06 21:11:05 $
 
 
 #package AWSHTTPCODES;
@@ -38,7 +37,7 @@
 '401'=>'Unauthorized',
 '402'=>'Payment required',
 '403'=>'Forbidden',
-'404'=>'Document Not Found',
+'404'=>'Document Not Found (hits on favicon excluded)',
 '405'=>'Method not allowed',
 '406'=>'Document not acceptable to client',
 '407'=>'Proxy authentication required',
